0.9.9 API documentation: fast_exponential.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

fast_exponential.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_fast_exponential is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_fast_exponential extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
34 template<typename genType>
35 GLM_FUNC_DECL genType fastPow(genType x, genType y);
36
39 template<length_t L, typename T, qualifier Q>
40 GLM_FUNC_DECL vec<L, T, Q> fastPow(vec<L, T, Q> const& x, vec<L, T, Q> const& y);
41
44 template<typename genTypeT, typename genTypeU>
45 GLM_FUNC_DECL genTypeT fastPow(genTypeT x, genTypeU y);
46
49 template<length_t L, typename T, qualifier Q>
50 GLM_FUNC_DECL vec<L, T, Q> fastPow(vec<L, T, Q> const& x);
51
54 template<typename T>
55 GLM_FUNC_DECL T fastExp(T x);
56
59 template<length_t L, typename T, qualifier Q>
60 GLM_FUNC_DECL vec<L, T, Q> fastExp(vec<L, T, Q> const& x);
61
64 template<typename T>
65 GLM_FUNC_DECL T fastLog(T x);
66
69 template<length_t L, typename T, qualifier Q>
70 GLM_FUNC_DECL vec<L, T, Q> fastLog(vec<L, T, Q> const& x);
71
74 template<typename T>
75 GLM_FUNC_DECL T fastExp2(T x);
76
79 template<length_t L, typename T, qualifier Q>
80 GLM_FUNC_DECL vec<L, T, Q> fastExp2(vec<L, T, Q> const& x);
81
84 template<typename T>
85 GLM_FUNC_DECL T fastLog2(T x);
86
89 template<length_t L, typename T, qualifier Q>
90 GLM_FUNC_DECL vec<L, T, Q> fastLog2(vec<L, T, Q> const& x);
91
93 }//namespace glm
94
95 #include "fast_exponential.inl"
glm::fastLog
GLM_FUNC_DECL vec< L, T, Q > fastLog(vec< L, T, Q > const &x)
Faster than the common exp2 function but less accurate.
glm::fastPow
GLM_FUNC_DECL vec< L, T, Q > fastPow(vec< L, T, Q > const &x)
Faster than the common pow function but less accurate.
glm::fastLog2
GLM_FUNC_DECL vec< L, T, Q > fastLog2(vec< L, T, Q > const &x)
Faster than the common log2 function but less accurate.
glm::fastExp2
GLM_FUNC_DECL vec< L, T, Q > fastExp2(vec< L, T, Q > const &x)
Faster than the common exp2 function but less accurate.
glm::fastExp
GLM_FUNC_DECL vec< L, T, Q > fastExp(vec< L, T, Q > const &x)
Faster than the common exp function but less accurate.
glm
Definition: common.hpp:20